@@ -29,13 +29,13 @@ def sql(key):
         'StreamId': {'sql': "SELECT id From DataStream;", 'database': 'AnyRobot'},
         'LogGroupIdPare': {'sql': 'SELECT groupId From LogGroup where GroupName!="所有日志";', 'database': 'AnyRobot'},
         'RoleId': {'sql': 'SELECT roleId From Role where roleName ="admin";', 'database': 'AnyRobot'},
-        'RoleId_Notadmin': {'sql': 'SELECT roleId From Role where roleName != "admin";', 'database': 'AnyRobot'},
+        'RoleId_Notadmin': {'sql': 'SELECT roleId From Role where roleName != "admin" AND roleName != "user";', 'database': 'AnyRobot'},
         'tagGroupID': {'sql': "SELECT id From TagGroup;", 'database': 'AnyRobot'},
         'tagID': {'sql': "SELECT id From Tag;", 'database': 'AnyRobot'},
         'HostID': {'sql': "SELECT id From AgentHost;", 'database': 'AnyRobot'},
         'HostIp': {'sql': "SELECT ip From AgentHost;", 'database': 'AnyRobot'},
         'openapiID': {'sql': "SELECT id From OpenAPIManager;", 'database': 'AnyRobotOpenLog'},
-        'UserID_Notadmin': {'sql': 'select userId from User where loginName != "admin";', 'database': 'AnyRobot'},
+        'UserID_Notadmin': {'sql': 'select userId from User where loginName != "admin" AND description != "不能删除的用户";', 'database': 'AnyRobot'},
         'JDBCCollectorId': {
             'sql': "select collectorId from JDBCCollectorConfig where JDBCCollectorConfig.type='jdbc' AND JDBCCollectorConfig.`sql`='select * from CollectorConfig';",
             'database': 'AnyRobot'},
