@@ -1,5 +1,5 @@
 from aishu import setting
-from aishu.datafaker.profession.entity import name, switch, ip, timestamp, ml, kai, objectManager, index, agent ,id ,port
+from aishu.datafaker.profession.entity import name, switch, ip, timestamp, ml, kai, objectManager, index, agent ,id ,port, DataManage
 from aishu.datafaker.profession.entity import zx
 from aishu.datafaker.profession.entity.ParaDateFiled import ParaDateFiledServer
 from aishu.datafaker.profession.entity.RetrievesAssociated import ParaDateAnyRobotServer
@@ -79,7 +79,8 @@ def filed(key,inquire=[]):
         'agentDeployIp':ip.date().getAentHostIp,
         'http_port':CreateTestPort.Port().httpport,
         'syslog_port':CreateTestPort.Port().syslogPort,
-        'FutureTime': ParaDateFiledServer().getFutureTime
+        'FutureTime': ParaDateFiledServer().getFutureTime,
+        'RoleId_user': DataManage.DataManage_Storage().RoleId_user
     }
 
     switcher = SERVICE_KPI_
